============
django-winds
============

A tool to collect and serve wind prediction data. Designed to have pluggable backends for multiple wind-prediction services. So far UCAR_ is the only source and covers just the continental US.

Installation
============

Use ``pip`` to install from PyPI::

	pip install django-winds

Add ``django_winds`` to your settings.py file::

	INSTALLED_APPS = (
	    ...
	    'django_winds',
	    ...
	)

Additional Requirements
=======================

``beautifulsoup4`` to parse the XML served by THREDDS

``django-tastypie`` to generate the API

Django Settings
===============

``DJANGO_WINDS_CACHE_TIMEOUT`` - Number of minutes to cache endpoint responses.

``DJANGO_WINDS_DEMO_MODE`` - True/False... not implemented yet.

Acquiring Data
==============

``django-winds`` is really just a extract and transport layer for data. It exposes an API that takes a Point (latitude/longitude) and returns wind predictions for that location.

Contributing
============

Think this needs something else? To contribute to ``django-tides`` create a fork on Bitbucket_. Clone your fork, make some changes, and submit a pull request.

Bugs are great contributions too! Feel free to add an issue on Bitbucket_.


.. _Bitbucket: https://bitbucket.org/bilgecode/django-tides
.. _UCAR: http://www2.ucar.edu/